@@ -32,14 +32,14 @@ class BTDataSource : public TransferDataSource
     Q_OBJECT
     public:
         BTDataSource(const QUrl &srcUrl, QObject *parent);
-        ~BTDataSource();
+        ~BTDataSource() override;
 
         void start() override;
         void stop() override;
         void addSegments(const QPair<KIO::fileoffset_t, KIO::fileoffset_t> &segmentSize, const QPair<int, int> &segmentRange) override;
         void getData(const KIO::fileoffset_t &off, const QByteArray &dataArray);
 
-    private slots:
+    private Q_SLOTS:
         void init(const QUrl &torrentSource, const QByteArray &data);
         void cacheAdded(BTCache *cache);
         void selectorAdded(BTChunkSelector *selector);
